@@ -56,8 +56,8 @@
 #define SOUND_SUFFIX ".wav"
 #define SOUND_FLOAT_SUFFIX ".fp"
 #define SOUND_DEFAULT_RATE 11025
-#define SOUND_DEFAULT_TYPE CharData
-#define HEADER_DEFAULT_TYPE Wav
+#define SOUND_DEFAULT_TYPE UnsignedCharData
+#define HEADER_DEFAULT_TYPE Wave
 #else
 #define SOUND_SUFFIX ".short"
 #define SOUND_FLOAT_SUFFIX ".fp"
@@ -70,7 +70,9 @@
 
 #include "next_sound.h"
 #define SOUNDSTRUCT_H
+#define DOUBLE_FORMAT SND_FORMAT_DOUBLE
 #define FLOAT_FORMAT SND_FORMAT_FLOAT
+#define INT_FORMAT SND_FORMAT_LINEAR_32
 #define SHORT_FORMAT SND_FORMAT_LINEAR_16
 #define MULAW_FORMAT SND_FORMAT_MULAW_8
 #define ALAW_FORMAT (27) /* SND_FORMAT_ALAW_8 */
@@ -80,8 +82,10 @@
 
 #include <multimedia/audio_filehdr.h>
 #define AUDIO_FILEHDR_H
+#define DOUBLE_FORMAT (7)
 #define FLOAT_FORMAT AUDIO_FILE_ENCODING_FLOAT
 #define SHORT_FORMAT AUDIO_FILE_ENCODING_LINEAR_16
+#define INT_FORMAT AUDIO_FILE_ENCODING_LINEAR_32
 #define MULAW_FORMAT AUDIO_FILE_ENCODING_MULAW_8
 #define ALAW_FORMAT (27)
 #define CHAR_FORMAT	AUDIO_FILE_ENCODING_LINEAR_8
@@ -90,7 +94,9 @@
 
 // these macros taken from NeXT header files -- hope they don't change.
 
+#define DOUBLE_FORMAT (7)
 #define FLOAT_FORMAT (6)
+#define INT_FORMAT (5)
 #define SHORT_FORMAT (3)
 #define CHAR_FORMAT (2)
 #define MULAW_FORMAT (1)
